@@ -20,6 +20,7 @@ from __future__ import annotations
 
 import logging
 import os
+import pathlib
 import pickle  # nosec B403
 import warnings
 from datetime import datetime, timedelta
@@ -38,7 +39,9 @@ LOG = logging.getLogger(__name__)
 
 # Old Name -> New Name
 PENDING_OLD_READER_NAMES = {"fci_l1c_fdhsi": "fci_l1c_nc", "viirs_l2_cloud_mask_nc": "viirs_edr"}
-OLD_READER_NAMES: dict[str, str] = {}
+OLD_READER_NAMES: dict[str, str] = {
+    "slstr_l2": "ghrsst_l2",
+}
 
 
 def group_files(files_to_sort, reader=None, time_threshold=10,
@@ -778,9 +781,20 @@ def _get_compression(file):
 
 
 def open_file_or_filename(unknown_file_thing):
-    """Try to open the *unknown_file_thing*, otherwise return the filename."""
-    try:
-        f_obj = unknown_file_thing.open()
-    except AttributeError:
+    """Try to open the provided file "thing" if needed, otherwise return the filename or Path.
+
+    This wraps the logic of getting something like an fsspec OpenFile object
+    that is not directly supported by most reading libraries and making it
+    usable. If a :class:`pathlib.Path` object or something that is not
+    open-able is provided then that object is passed along. In the case of
+    fsspec OpenFiles their ``.open()`` method is called and the result returned.
+
+    """
+    if isinstance(unknown_file_thing, pathlib.Path):
         f_obj = unknown_file_thing
+    else:
+        try:
+            f_obj = unknown_file_thing.open()
+        except AttributeError:
+            f_obj = unknown_file_thing
     return f_obj
