@@ -198,9 +198,10 @@ SENSORS = {
 def mjd2datetime64(mjd):
     """Convert Modified Julian Day (MJD) to datetime64."""
     epoch = np.datetime64("1858-11-17 00:00")
-    day2usec = 24 * 3600 * 1E6
-    mjd_usec = (mjd * day2usec).astype(np.int64).astype("timedelta64[us]")
-    return epoch + mjd_usec
+    day2nsec = 24 * 3600 * 1E9
+    mjd_nsec = (mjd * day2nsec).astype(np.int64).astype("timedelta64[ns]")
+
+    return epoch + mjd_nsec
 
 
 class HRITJMAFileHandler(HRITFileHandler):
