@@ -63,7 +63,7 @@ class VGACFileHandler(BaseFileHandler):
 
     def fix_radiances_not_in_percent(self, data):
         """Scale radiances to percent. This was not done in first version of data."""
-        return 100*data
+        return 100 * data
 
     def set_time_attrs(self, data):
         """Set time from attributes."""
@@ -73,6 +73,33 @@ class VGACFileHandler(BaseFileHandler):
             self._end_time = data.attrs["end_time"]
             self._start_time = data.attrs["start_time"]
 
+    def dt64_to_datetime(self, dt64):
+        """Conversion of numpy.datetime64 to datetime objects."""
+        if isinstance(dt64, np.datetime64):
+            return dt64.astype(datetime)
+        return dt64
+
+    def extract_time_data(self, data, nc):
+        """Decode time data."""
+        reference_time = np.datetime64(datetime.strptime(nc["proj_time0"].attrs["units"],
+                                                         "days since %d/%m/%YT%H:%M:%S"))
+        delta_part_of_day, delta_full_days = np.modf(nc["proj_time0"].values)
+        delta_full_days = np.timedelta64(delta_full_days.astype(np.int64), "D").astype("timedelta64[us]")
+        delta_part_of_day = delta_part_of_day * np.timedelta64(1, "D").astype("timedelta64[us]")
+        delta_hours = data.values * np.timedelta64(1, "h").astype("timedelta64[us]")
+        time_data = xr.DataArray(reference_time + delta_full_days + delta_part_of_day + delta_hours,
+                                 coords=data.coords, attrs={"long_name": "Scanline time"})
+        return time_data
+
+    def decode_time_variable(self, data, file_key, nc):
+        """Decide if time data should be decoded."""
+        if file_key != "time":
+            return data
+        if data.attrs["units"] == "hours since proj_time0":
+            return self.extract_time_data(data, nc)
+        else:
+            raise AttributeError('Unit of time variable in VGAC nc file is not "hours since proj_time0"')
+
     def get_dataset(self, key, yaml_info):
         """Get dataset."""
         logger.debug("Getting data for: %s", yaml_info["name"])
@@ -82,6 +109,7 @@ class VGACFileHandler(BaseFileHandler):
         file_key = yaml_info.get("nc_key", name)
         data = nc[file_key]
         data = self.calibrate(data, yaml_info, file_key, nc)
+        data = self.decode_time_variable(data, file_key, nc)
         data.attrs.update(nc.attrs)  # For now add global attributes to all datasets
         data.attrs.update(yaml_info)
         self.set_time_attrs(data)
