@@ -75,7 +75,9 @@ def test_startend(himl2_filename):
 
 def test_ahi_l2_area_def(himl2_filename, caplog):
     """Test reader handles area definition correctly."""
-    ps = "+proj=geos +lon_0=140.7 +h=35785863 +x_0=0 +y_0=0 +a=6378137 +rf=298.257024882273 +units=m +no_defs +type=crs"
+    from pyproj import CRS
+
+    ps = "+a=6378137 +h=35785863 +lon_0=140.7 +no_defs +proj=geos +rf=298.257024882273 +type=crs +units=m +x_0=0 +y_0=0"
 
     # Check case where input data is correct size.
     fh = ahil2_filehandler(himl2_filename)
@@ -84,7 +86,9 @@ def test_ahi_l2_area_def(himl2_filename, caplog):
     assert area_def.width == dimensions["Columns"]
     assert area_def.height == dimensions["Rows"]
     assert np.allclose(area_def.area_extent, exp_ext)
-    assert area_def.proj4_string == ps
+
+    expected_crs = CRS(ps)
+    assert area_def.crs == expected_crs
 
     # Check case where input data is incorrect size.
     fh = ahil2_filehandler(himl2_filename)
